diff --git a/iso3166-country-codes.cabal b/iso3166-country-codes.cabal
--- a/iso3166-country-codes.cabal
+++ b/iso3166-country-codes.cabal
@@ -1,4 +1,4 @@
-Version: 0.20101223.3
+Version: 0.20110810.3
 Name:		iso3166-country-codes
 Cabal-Version:  >= 1.6
 Build-type:	Simple

diff --git a/Data/ISO3166_CountryCodes.hs b/Data/ISO3166_CountryCodes.hs
--- a/Data/ISO3166_CountryCodes.hs
+++ b/Data/ISO3166_CountryCodes.hs
@@ -118,7 +118,7 @@
    |
    BO -- ^ BOLIVIA, PLURINATIONAL STATE OF
    |
-   BQ -- ^ BONAIRE, SAINT EUSTATIUS AND SABA
+   BQ -- ^ BONAIRE, SINT EUSTATIUS AND SABA
    |
    BA -- ^ BOSNIA AND HERZEGOVINA
    |
@@ -478,6 +478,8 @@
    |
    GS -- ^ SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS
    |
+   SS -- ^ SOUTH SUDAN
+   |
    ES -- ^ SPAIN
    |
    LK -- ^ SRI LANKA
@@ -594,7 +596,7 @@
 countryNameFromCode BM = "BERMUDA"
 countryNameFromCode BT = "BHUTAN"
 countryNameFromCode BO = "BOLIVIA, PLURINATIONAL STATE OF"
-countryNameFromCode BQ = "BONAIRE, SAINT EUSTATIUS AND SABA"
+countryNameFromCode BQ = "BONAIRE, SINT EUSTATIUS AND SABA"
 countryNameFromCode BA = "BOSNIA AND HERZEGOVINA"
 countryNameFromCode BW = "BOTSWANA"
 countryNameFromCode BV = "BOUVET ISLAND"
@@ -774,6 +776,7 @@
 countryNameFromCode SO = "SOMALIA"
 countryNameFromCode ZA = "SOUTH AFRICA"
 countryNameFromCode GS = "SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS"
+countryNameFromCode SS = "SOUTH SUDAN"
 countryNameFromCode ES = "SPAIN"
 countryNameFromCode LK = "SRI LANKA"
 countryNameFromCode SD = "SUDAN"